@@ -70,7 +70,17 @@ test_that("format_table with NA values", {
 skip_if_not_installed("bayestestR")
 set.seed(1234)
 test_that("format_table with multiple si-levels", {
+  skip_on_cran()
   d <- bayestestR::distribution_normal(1000)
   x <- bayestestR::hdi(d, ci = c(0.80, 0.90))
-  expect_snapshot(x)
+  expect_identical(
+    capture.output(x),
+    c(
+      "Highest Density Interval",
+      "",
+      "80% HDI       |       90% HDI",
+      "-----------------------------",
+      "[-1.28, 1.28] | [-1.65, 1.64]"
+    )
+  )
 })
